#!/bin/bash

# Set condor to drain mode when close to wall time limit.

# Make sure default environment is sourced
if [ -f "/etc/environment" ]; then
    . "/etc/environment"
fi

LIMIT=.85 # percentage of wall time reached after with condor will be set to drain mode
WALL_TIME_FILE="/root/wall_time" # content = wall time, creation time = start time
DEBUG=0

if [ -n $WALLTIME ]; then
    WALL_TIME=$WALLTIME
    START_TIME=$BOOTTIME
elif [ -f $WALL_TIME_FILE ]; then
    WALL_TIME=$(<$WALL_TIME_FILE)
    START_TIME=$(stat -c %Y $WALL_TIME_FILE)
else
    echo "ERROR: Wall time file ($WALL_TIME_FILE) does not exist."
    exit 1
fi

CURR_TIME=$(date +%s)
LIMIT_REACHED=$(echo "scale=3; ($CURR_TIME-$START_TIME)/$WALL_TIME >= $LIMIT" | bc)

if (( $DEBUG == 1 )); then
    echo "limit: $LIMIT"
    echo "wall time: $WALL_TIME"
    echo "start time: $START_TIME"
    echo "current time: $CURR_TIME"
    echo "scale=3; ($CURR_TIME-$START_TIME)/$WALL_TIME" | bc
    echo "limit reached: $LIMIT_REACHED"
fi

if (( $LIMIT_REACHED == 1 )); then
    echo "Close to wall time limit ($LIMIT). Will finish running jobs and exit."
    # don't accept new jobs but finish running ones
    condor_drain $(condor_config_val FULL_HOSTNAME)
fi
